@@ -68,14 +68,18 @@ class account():
 
     def connect(self):
         if self.accountdata.password:
+            print "Establishing api for " + self.accountdata.servicename + " using basic auth"
             self.api = twitter.Api(username=self.accountdata.username, password=self.accountdata.password)
             self.api.SetBaseUrl(self.accountdata.baseUrl)
             self.api.SetBaseSearchUrl(self.accountdata.searchUrl)
         if (self.accountdata.access_token != None):
+            print "Establishing api for " + self.accountdata.servicename + " using oauth"
             self.api = oauthtwitter.OAuthApi(self.CONSUMER_KEY, self.CONSUMER_SECRET, self.accountdata.access_token)
         if (self.api == None):
+            print "Failed to establish api for " + +self.accountdata.servicename
             return False
         else:
+            print "Connection working ok"
             return True
 
     def getAccountData(self):
@@ -701,7 +705,7 @@ class account():
 
         #see if we have just an empty string (eg eroneous button press)
         if (tweet == ""):
-            return
+            return False
 
         try:
 
@@ -729,9 +733,9 @@ class account():
                         reason = ""
                     msg = msg + 'Server returned ' + str(e.code) + " : " + reason
 
-            note = hildon.hildon_note_new_information(self.window, msg)
-            note.run()
-            note.destroy()
+            note = osso.SystemNote(self.osso_c)
+
+            result = note.system_note_infoprint(msg)
             return False
 
     def FollowUser(self, widget, name, *args):
@@ -798,7 +802,6 @@ class account():
     def get_pic_for_name (self, name):
         item = self.avatars.get_iter_first()
         while (item != None):
-            print "comparing " + self.avatars.get_value(item, 3) + " to " + name
             if (self.avatars.get_value(item, 3) == name):
                 return self.avatars.get_value(item, 0)
             item = self.avatars.iter_next(item)
